function [itest,xtest,hptest,MPtest]=mpline(i,x,hp,MP)
% function [itest,xtest,hptest,MPtest]=mpline(i,x,hp,MP)
% i=1-16
% itest is the array giving the element numbers of the ith mp line in x and hp.
% xtest is the x coordinate of the ith mpm line.
% hptest is the hp valus for the ith mp line.
% MPtest is a scalar manifold pressure of the ith line.
istart=1+5*(i-1);
iend=istart+4;
itest=istart:iend;
xtest=x(itest);
hptest=hp(itest);
MPtest=MP(i);
